Crate uni_addr

Crate uni_addr 

uni-addr

Test pipeline Crates.io Docs.rs License: MIT OR Apache-2.0

[!NOTE] Since version 0.4.0, this crate is renamed to uaddr and the crate under the original name uni-addr is now a wrapper crate of uaddr. Consider using uaddr directly.

This crate provides a unified address type that can represent a std::net::SocketAddr, a std::os::unix::net::SocketAddr, or a host name with port.

License

Licensed under either of:

at your option.

Modules

error
Error types for uaddr.
host
Syntactically valid DNS name (hostname) with a port.
unix
UNIX domain socket (UDS) address.

Structs

HostAddr
A syntactically valid DNS name (hostname) with a port.
UnixAddr
A UNIX domain socket (UDS) address.

Enums

UniAddr
A unified address type that can represent: